@@ -39,7 +39,7 @@ class CreatedUserModel(Model):
         db_constraint=get_kelove_databases_settings('DB_CONSTRAINT_USER', False),
         null=True,
         blank=True,
-        editable=True,
+        editable=get_kelove_databases_settings('USER_EDITABLE', False),
         default=None
     )
 
@@ -61,7 +61,7 @@ class UpdatedUserModel(Model):
         db_constraint=get_kelove_databases_settings('DB_CONSTRAINT_USER', False),
         null=True,
         blank=True,
-        editable=True,
+        editable=get_kelove_databases_settings('USER_EDITABLE', False),
         default=None
     )
 
